@@ -2,9 +2,10 @@
 
 import json
 
-from django.utils.timezone import now
 from django.http import HttpResponse
 
+from proxylist import now
+
 
 def mirror(request):
     """
